#include <qpainter.h>
#include <kapp.h>
#include <kaction.h>
#include <kmenubar.h>
#include <kstdaccel.h>
#include "kdemowindow.moc" // von eigener Klasse das .moc inkludieren
#include "kmodaldemodialog.h" // von anderen Klassen das .h inkludieren

KDemoWindow :: KDemoWindow() :
hasOutline(true),
linewidthCode(0),
hasFill(true),
outlineColor(QColor(255, 0, 0)),
fillColor(QColor(128, 128, 128)),
position(0)
{	
	setCaption("KDE-Dialog-Demo");

	nonModalDemo = new KNonModalDemoDialog(this);
	connect(nonModalDemo, SIGNAL(finished()), this, SLOT(enableMenuEntry()));
	connect(nonModalDemo, SIGNAL(newPosition(int)), this, SLOT(readNewPosition(int)));

	KAction* openModalDialogAction = new KAction ("&Modaler Dialog", CTRL+Key_M, this, SLOT(openModalDialog()), this);
	openNonModalDialogAction = new KAction ("&Nichtmodaler Dialog", CTRL+Key_N, this, SLOT(openNonModalDialog()), this);
	KAction* quitAction = new KAction ("B&eenden", KStdAccel::quit(), KApplication::kApplication(), SLOT(closeAllWindows()), this);

	QPopupMenu *myMenu = new QPopupMenu();
	openModalDialogAction->plug(myMenu);
	openNonModalDialogAction->plug(myMenu);
	myMenu->insertSeparator();
	quitAction->plug(myMenu);
	menuBar()->insertItem ("&Testmen", myMenu);
}

KDemoWindow :: ~KDemoWindow()
{
	nonModalDemo->delayedDestruct();
}

void KDemoWindow :: openModalDialog()
{
	KModalDemoDialog d(this);

	// Dialog mit aktuellen Werten vorbelegen
	d.checkOutline->setChecked(hasOutline);
	d.groupLinewidth->setEnabled(hasOutline); // Buttons grau/inaktiv schalten, falls false 
	d.groupLinewidth->setButton(linewidthCode);
	d.checkFill->setChecked(hasFill);
	d.outlineColorButton->setColor(outlineColor);
	d.fillColorButton->setColor(fillColor);

	int result = d.exec();
	
	if(result != KDialog::Accepted)
	{
		return;
	}

	// Dialog auslesen
	hasOutline = d.checkOutline->isChecked();
	linewidthCode = d.groupLinewidth->id(d.groupLinewidth->selected());
	hasFill = d.checkFill->isChecked();
	outlineColor = d.outlineColorButton->color();
	fillColor = d.fillColorButton->color();
	
	update(); // mit den genderten Einstellungen neuzeichnen
}

void KDemoWindow :: openNonModalDialog()
{
	openNonModalDialogAction->setEnabled(false);
	nonModalDemo->show();
}

void KDemoWindow :: paintEvent (QPaintEvent *dummy)
{
	QPainter myPainter(this);
	
	QPen thePen(Qt::NoPen);
	if(hasOutline)
	{
		thePen = QPen(outlineColor, 2*(linewidthCode+1)); // linewidthCode = 0, 1, 2	
	}
	myPainter.setPen(thePen);

	QBrush theBrush(Qt::NoBrush);
	if(hasFill)
	{
		theBrush = QBrush(fillColor);
	}
	myPainter.setBrush(theBrush);

	myPainter.drawEllipse(40+position, 40, 140, 140);
}

void KDemoWindow :: enableMenuEntry ()
{
	openNonModalDialogAction->setEnabled(true);
}

void KDemoWindow :: readNewPosition (int pos)
{
	position = pos;
	update();
}
